function [freal,fimag] = asf_values(element,energy);
% Usage: [freal,fimag] = asf_values(element,energy);
%
% This function uses the tables published online at 
% http://www.cxro.lbl.gov/optical_constants/asf.html
% to obtain approximate values for f' and f'' at a 
% given energy value.  The program selects the values 
% from the tabulated value with the closest energy.
% At the moment, there is no interpolation.
% 
% The energy should be input in eV units.
% The element should be written as 'Co', for example, 
% with apostrophes and using the symbol, not full name.
%
% Elizabeth Blackburn, 08/08/2006.

% Load the appropriate data table
% -------------------------------
filename = strcat(element,'.txt');
data_table = load(filename);
[a,b] = size(data_table);

% Find tabulated energy closest to input value
% --------------------------------------------
holder = find(data_table(:,1) > energy);
locator = holder(1);
islow   = data_table(locator-1,1);
ishigh  = data_table(locator,1);
delta_low = energy - islow;
delta_high = ishigh - energy;
if delta_low <= delta_high
    locator = locator-1;
else
    locator = locator;
end

% Output values
% -------------
freal = data_table(locator,2);
fimag = data_table(locator,3);


